@@ -5,7 +5,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 use DBI 1.40;
 use parent 'DBI';
@@ -85,7 +85,7 @@ sub connect_uncached {
         @{$connection}{qw( dsn user pass attr )} = @_;
 
         $self->_param( 'connection'   => $connection );
-        $self->_param( 'sql_abstract' => SQL::Abstract::Complete->new() );
+        $self->_param( 'sql_abstract' => SQL::Abstract::Complete->new );
 
         my $dialect = ( ref $connection eq 'HASH' and ref $connection->{attr} eq 'HASH' )
             ? $connection->{attr}{dq_dialect}
@@ -105,10 +105,10 @@ sub connect_uncached {
         my $self = shift;
 
         return
-            ( @_ == 0 and wantarray() )     ? @{ $self->_param('connection') }{ qw( dsn user pass attr ) } :
-            ( @_ == 0 and not wantarray() ) ? $self->_param('connection')                                  :
-            ( @_ > 1 and wantarray() )      ? @{ $self->_param('connection') }{@_}                         :
-            ( @_ > 1 and not wantarray() )  ? [ @{ $self->_param('connection') }{@_} ]                     :
+            ( @_ == 0 and wantarray     ) ? @{ $self->_param('connection') }{ qw( dsn user pass attr ) } :
+            ( @_ == 0 and not wantarray ) ? $self->_param('connection')                                  :
+            ( @_ > 1 and wantarray      ) ? @{ $self->_param('connection') }{@_}                         :
+            ( @_ > 1 and not wantarray  ) ? [ @{ $self->_param('connection') }{@_} ]                     :
             @{ $self->_param('connection') }{@_};
     }
 
@@ -221,7 +221,7 @@ sub connect_uncached {
         my ( $sql, @variables ) = $self->_param('sql_abstract')->delete( $table_name, $params );
         my $sth = $self->sql( $sql, $attr, $cache_type, \@variables );
 
-        $sth->run();
+        $sth->run;
         return $self;
     }
 
@@ -231,7 +231,7 @@ sub connect_uncached {
         my ( $sql, @variables ) = $self->_param('sql_abstract')->update( $table_name, $params, $where );
         my $sth = $self->sql( $sql, $attr, $cache_type, \@variables );
 
-        $sth->run();
+        $sth->run;
         return $self;
     }
 
@@ -338,7 +338,7 @@ sub connect_uncached {
         my $query = $self->_param('query');
         $query->{'where'} = { %{ $query->{'where'} || {} }, ( ref( $_[0] ) eq 'HASH' ) ? %{ $_[0] } : @_ };
 
-        return $self->up()->get( @{$query}{ qw( tables columns where meta attr cache_type ) } );
+        return $self->up->get( @{$query}{ qw( tables columns where meta attr cache_type ) } );
     }
 
     sub run {
@@ -367,7 +367,7 @@ sub connect_uncached {
 
         my $sql = $self->_param('sql');
 
-        $DBIx::Query::_dq_parser_cache->{$sql} ||= $self->_param('dq')->_param('sql_parser')->structure() if (
+        $DBIx::Query::_dq_parser_cache->{$sql} ||= $self->_param('dq')->_param('sql_parser')->structure if (
             not $DBIx::Query::_dq_parser_cache->{$sql} and
             $self->_param('dq')->_param('sql_parser')->parse($sql)
         );
@@ -409,7 +409,7 @@ sub connect_uncached {
     }
 
     sub table {
-        return shift->structure()->{'table_names'}[0];
+        return shift->structure->{'table_names'}[0];
     }
 
     sub _wildcard_column {
@@ -418,7 +418,7 @@ sub connect_uncached {
         my $wildcard_column = $self->_param('wildcard_column');
         return $wildcard_column if ( defined $wildcard_column );
 
-        $self->structure();
+        $self->structure;
         return $self->_param('wildcard_column');
     }
 
@@ -444,13 +444,13 @@ sub connect_uncached {
         my ( $self, $skip ) = @_;
         $skip ||= 0;
 
-        my $method = ( $self->{'sth'}->_wildcard_column() ) ? 'fetchrow_hashref' : 'fetchrow_arrayref';
+        my $method = ( $self->{'sth'}->_wildcard_column ) ? 'fetchrow_hashref' : 'fetchrow_arrayref';
 
         my $value;
         DBIx::Query::_Common::_try( $self, sub {
-            $self->{'sth'}->fetchrow_arrayref() while ( $skip-- );
+            $self->{'sth'}->fetchrow_arrayref while ( $skip-- );
 
-            if ( my $row = $self->{'sth'}->$method() ) {
+            if ( my $row = $self->{'sth'}->$method ) {
                 $value = DBIx::Query::_Dq::Row->new( $row, $self );
             }
 
@@ -474,10 +474,10 @@ sub connect_uncached {
 
     sub each {
         my ( $self, $code ) = @_;
-        my $method = ( $self->{'sth'}->_wildcard_column() ) ? 'fetchrow_hashref' : 'fetchrow_arrayref';
+        my $method = ( $self->{'sth'}->_wildcard_column ) ? 'fetchrow_hashref' : 'fetchrow_arrayref';
 
         DBIx::Query::_Common::_try( $self, sub {
-            $code->( DBIx::Query::_Dq::Row->new( $_, $self ) ) while ( $_ = $self->{'sth'}->$method() );
+            $code->( DBIx::Query::_Dq::Row->new( $_, $self ) ) while ( $_ = $self->{'sth'}->$method );
             $self->{'sth'}->finish;
         } );
 
@@ -489,8 +489,8 @@ sub connect_uncached {
 
         my @value;
         DBIx::Query::_Common::_try( $self, sub {
-            @value = $self->{'sth'}->fetchrow_array();
-            $self->{'sth'}->finish();
+            @value = $self->{'sth'}->fetchrow_array;
+            $self->{'sth'}->finish;
         } );
 
         my $wantarray = wantarray;
@@ -525,7 +525,7 @@ sub connect_uncached {
 
     sub column {
         my $self   = shift;
-        my @values = map { $_->[0] } @{ ( $self->all() )[0] };
+        my @values = map { $_->[0] } @{ ( $self->all )[0] };
 
         return (wantarray) ? @values : \@values;
     }
@@ -556,7 +556,7 @@ sub connect_uncached {
 
     sub cell {
         my ( $self, $index, $new_value ) = @_;
-        my ( $name, $structure, $value ) = ( $index, $self->up()->up()->structure(), undef );
+        my ( $name, $structure, $value ) = ( $index, $self->up->up->structure, undef );
 
         croak('Query used earlier in chain failed to parse, so cell() cannot be called')
             unless ( ref($structure) eq 'HASH' );
@@ -599,7 +599,7 @@ sub connect_uncached {
         for ( my $i = 0 ; $i < @{ $self->{'row'} } ; $i++ ) {
             $code->(
                 DBIx::Query::_Dq::Cell->new(
-                    $self->up()->up()->structure()->{'column_lookup'}{$i},
+                    $self->up->up->structure->{'column_lookup'}{$i},
                     $self->{'row'}[$i],
                     $i, $self,
                 )
@@ -613,7 +613,7 @@ sub connect_uncached {
         my ($self) = @_;
 
         if ( ref( $self->{'row'} ) eq 'ARRAY' ) {
-            my $structure = $self->up()->up()->structure();
+            my $structure = $self->up->up->structure;
             if ( ref($structure) eq 'HASH' and $structure->{'column_invert_lookup'} ) {
                 return {
                     map {
@@ -642,21 +642,21 @@ sub connect_uncached {
 
         croak('save() called without a key or set of keys') unless ($key);
 
-        my $data = $self->data();
+        my $data = $self->data;
         if ( ref($params) eq 'HASH' ) {
             $data->{$_} = $params->{$_} foreach ( keys %{$params} );
         }
 
-        my $dq = $self->up()->up()->up();
+        my $dq = $self->up->up->up;
 
         my ( $sql, @variables ) = $dq->_param('sql_abstract')->update(
-            $self->up()->up()->table(),
+            $self->up->up->table,
             $data,
             { map { $_ => delete $data->{$_} } ( ref($key) ? @{$key} : $key ) },
         );
         my $sth = $dq->sql( $sql, undef, $cache_type, \@variables );
 
-        $sth->run();
+        $sth->run;
         return $self;
     }
 
@@ -691,7 +691,7 @@ sub connect_uncached {
 
     sub value {
         my ( $self, $new_value ) = @_;
-        return ( defined $new_value ) ? $self->up()->cell( $self->name(), $new_value ) : $self->{'value'};
+        return ( defined $new_value ) ? $self->up->cell( $self->name, $new_value ) : $self->{'value'};
     }
 
     sub index {
@@ -699,7 +699,7 @@ sub connect_uncached {
     }
 
     sub save {
-        return shift->up()->save(@_);
+        return shift->up->save(@_);
     }
 
     sub up {
@@ -721,7 +721,7 @@ DBIx::Query - Simplified abstracted chained DBI subclass
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/DBIx-Query.svg)](https://travis-ci.org/gryphonshafer/DBIx-Query)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/DBIx-Query/badge.png)](https://coveralls.io/r/gryphonshafer/DBIx-Query)
@@ -740,31 +740,31 @@ version 1.08
     );
 
     # get stuff, things, and everything easily
-    my $everything = $dq->get('things')->run()->all({});
-    my $things     = $dq->get( 'things', ['stuff'], { 'value' => 42 } )->run()->all();
-    my $stuff      = $dq->sql('SELECT stuff FROM things WHERE value = ?')->run(42)->all();
+    my $everything = $dq->get('things')->run->all({});
+    my $things     = $dq->get( 'things', ['stuff'], { 'value' => 42 } )->run->all;
+    my $stuff      = $dq->sql('SELECT stuff FROM things WHERE value = ?')->run(42)->all;
 
     # can use DBI methods at any point
     my $sth = $dq->get('things');
-    $sth->execute();
-    $stuff = $sth->fetchall_arrayref();
+    $sth->execute;
+    $stuff = $sth->fetchall_arrayref;
 
     # get all from data where a is 42 (as an arrayref of hashrefs)
-    my $data = $dq->get('data')->where( 'a' => 42 )->run()->all({});
+    my $data = $dq->get('data')->where( 'a' => 42 )->run->all({});
 
     my $row_set = $dq->sql('SELECT a, b FROM data WHERE x = ?')->run(42);
-    my $row_0   = $row_set->next();
-    my $a_value = $row_0->cell('a')->value();
+    my $row_0   = $row_set->next;
+    my $a_value = $row_0->cell('a')->value;
 
     use Data::Dumper 'Dumper';
-    $dq->sql('SELECT a, b, c FROM data')->run()->each( sub {
+    $dq->sql('SELECT a, b, c FROM data')->run->each( sub {
         my ($row) = @_;
-        print Dumper( $row->data() ), "\n";
+        print Dumper( $row->data ), "\n";
     } );
 
-    my $row = $dq->sql('SELECT id, name FROM data')->run()->next();
+    my $row = $dq->sql('SELECT id, name FROM data')->run->next;
 
-    $row->cell( 'name', 'New Value' )->up()->save('id');
+    $row->cell( 'name', 'New Value' )->up->save('id');
     $row->save( 'id', { 'name' => 'New Value' } );
     $row->save( 'id', { 'name' => 'New Value' }, 0 );
 
@@ -780,22 +780,22 @@ of like cookies without a glass of milk. With DBIx::Query, you can construct
 queries either with SQL or abstract Perl data structures described by
 L<SQL::Abstract::Complete>.
 
-    my $stuff  = $dq->sql('SELECT stuff FROM things WHERE value = ?')->run(42)->all();
-    my $things = $dq->get( 'things', ['stuff'], { 'value' = 42 } )->run()->all();
+    my $stuff  = $dq->sql('SELECT stuff FROM things WHERE value = ?')->run(42)->all;
+    my $things = $dq->get( 'things', ['stuff'], { 'value' = 42 } )->run->all;
 
 The overall point being that you can chain various parts of the query prepare,
 execute, and data retrieval process to dramatically reduce repeated code in
 most programs.
 
-    my $c_value    = $dq->sql('SELECT a FROM b WHERE c = ?')->run($c)->value();
-    my $everything = $dq->get('things')->run()->all({});
+    my $c_value    = $dq->sql('SELECT a FROM b WHERE c = ?')->run($c)->value;
+    my $everything = $dq->get('things')->run->all({});
 
 DBIx::Query is a pure subclass of DBI, so it can be used exactly like DBI. At
 any point, you can drop out of DBIx::Query-specific methods and use DBI methods.
 
     my $sth = $dq->get('things');
-    $sth->execute();
-    my $stuff = $sth->fetchall_arrayref();
+    $sth->execute;
+    my $stuff = $sth->fetchall_arrayref;
 
 Like L<DBI>, there are multiple sub-classes each with a set of methods related
 to its level. In L<DBI>, there is:
@@ -838,7 +838,7 @@ cell
 
 The following methods exists at the "parent class" level.
 
-=head2 connect()
+=head2 connect
 
 This method is mostly inherritted from L<DBI>'s C<connect_cached()>. Since
 DBIx::Query is a true subclass of L<DBI>, typically the only thing you have to
@@ -875,12 +875,12 @@ parse.
 For more information, see L<SQL::Parser> documentation on dialect. If not
 specified, DBIx::Query defaults to the "ANSI" dialect.
 
-=head2 connect_uncached()
+=head2 connect_uncached
 
 If you'd prefer L<DBI>'s normal, uncached C<connect()> behavior, you can use
 C<connect_uncached()>.
 
-=head2 errstr()
+=head2 errstr
 
 This method is inherritted from L<DBI>.
 
@@ -890,7 +890,7 @@ The following methods are "primary" methods of the database class, the object
 returned from a C<connect()> call. "Primary" in this case means common use
 methods you'll probably want to know about.
 
-=head2 connection()
+=head2 connection
 
 Once you have established a connection, you can retrieve information about that
 connection using this method. It expects either no input or a list of strings
@@ -908,16 +908,27 @@ arrayref or array depending on context.
 If no values are provided, this method returns a hashref or an array of values
 depending on the context.
 
-    my $hashref = $dq->connection();
-    my @array   = $dq->connection();
+    my $hashref = $dq->connection;
+    my @array   = $dq->connection;
 
-=head2 sql()
+=head2 sql
 
 This method accepts SQL and optional attributes, cache type definition, and
 variables and returns a DBIx::Query statement handle.
 
     my $sth = $db->sql('SELECT alpha, beta, COUNT(*) FROM things WHERE delta > ?');
 
+The method must be passed SQL as its first input, then it can accept optional
+inputs in the order: attributes hashref, cache type integer, and variables
+arrayref.
+
+    my $sth = $db->sql(
+        'SELECT alpha, beta, COUNT(*) FROM things WHERE delta > ?',
+        {},
+        3,
+        [42],
+    );
+
 If the cache type definition is C<undef>, then DBIx::Query will set it to 3.
 (See L<DBI> for details of what the 1, 2, and 3 level caching means.) If you'd
 prefer no caching, you can set cache type to -1 or use C<sql_uncached>.
@@ -927,19 +938,12 @@ C<prepare_cached()> call. The values (if any are provided) are stored in the
 statement handle and used as default values if none are provided later during
 C<run()>.
 
-    my $sth = $db->sql(
-        'SELECT alpha, beta, COUNT(*) FROM things WHERE delta > ?',
-        { 'Columns' => [ 1, 2 ] },
-        1,
-        10,
-    )->run();
-
-=head2 sql_uncached()
+=head2 sql_uncached
 
 This method is the equivalent of C<sql()> with the cache value set to -1, which
 results in a normal C<prepare> call instead of C<prepare_cached>.
 
-=head2 get()
+=head2 get
 
 The second way to build a statement handle is through the use of C<get()>,
 which expects some number of input parameters that are fed into
@@ -962,12 +966,12 @@ If the cache type definition is C<undef>, then DBIx::Query will set it to 3.
 (See L<DBI> for details of what the 1, 2, and 3 level caching means.) If you'd
 prefer no caching, you can set cache type to -1 or use C<sql_uncached>.
 
-=head2 get_uncached()
+=head2 get_uncached
 
 This method is the equivalent of C<get()> with the cache value set to -1, which
 results in a normal C<prepare> call instead of C<prepare_cached>.
 
-=head2 add()
+=head2 add
 
 Inserts a row into the database and returns the primary key for that row if
 available.
@@ -982,7 +986,7 @@ definition is C<undef>, then DBIx::Query calls L<DBI>'s C<prepare()>, else it
 calls C<prepare_cached()> and uses the cache type as the C<$if_active>.
 (See the L<DBI> documentation.)
 
-=head2 rm()
+=head2 rm
 
 Deletes a row from the database and returns the object from which the method
 was called.
@@ -995,7 +999,7 @@ cache type definition is C<undef>, then DBIx::Query calls L<DBI>'s C<prepare()>,
 else it calls C<prepare_cached()> and uses the cache type as the C<$if_active>.
 (See the L<DBI> documentation.)
 
-=head2 update()
+=head2 update
 
 Updates a row in the database and returns the object from which the method
 was called.
@@ -1021,34 +1025,60 @@ prefer no caching, you can set cache type to -1 or use C<sql_uncached>.
 The following methods are "helper" methods of the database class, the object
 returned from a C<connect()> call.
 
-=head2 get_run()
+=head2 get_run
 
 Takes the same parameters as C<get>. It internally calls C<get()> followed
 by C<execute()>, then returns the executed statement handle.
 
-=head2 fetch_value()
+    my @movie_titles_page = $dq->get_run(
+        'movie',
+        ['title'],
+        undef,
+        {
+            'group_by' => 'title',
+            'having'   => [ { 'MAX(sales)' => { '>' => 9 } } ],
+            'order_by' => [ 'title', { '-desc' => 'budget' }, 'studio' ],
+            'rows'     => 5,
+            'page'     => 3,
+        },
+    )->column;
+
+=head2 fetch_value
 
 Takes the same parameters as C<get>. It internally calls C<get_run()> and
 returns the first row, first column value.
 
-=head2 fetchall_arrayref()
+    my $highest_grossing_movie_title = $dq->fetch_value(
+        'movie',
+        ['title'],
+        undef,
+        { 'order_by' => [ { '-desc' => 'budget' }, 'title', studio' ] },
+    );
+
+=head2 fetchall_arrayref
 
 Takes the same parameters as C<get>. It internally calls C<get_run()> followed
 by C<execute()>, then returns the results of a C<fetchall_arrayref()> on the
 executed statement handle.
 
-=head2 fetchall_hashref()
+    my $movies = $dq->fetchall_arrayref( 'movie', [ 'title', 'studio' ] );
+
+=head2 fetchall_hashref
 
 Basically the same thing as C<fetchall_arrayref()> called on the database class
 except it returns an array of hashrefs. (It just calls C<fetchall_arrayref({})>
 on the statement handle.)
 
-=head2 fetch_column_arrayref()
+    my $movies = $dq->fetchall_hashref( 'movie', [ 'title', 'studio' ] );
+
+=head2 fetch_column_arrayref
 
 Takes the same parameters as C<get>. It internally calls C<fetchall_arrayref()>
 against the database class and returns the first column's values as an arrayref.
 
-=head2 fetchrow_hashref()
+    my $movie_titles = $dq->fetchall_hashref( 'movie', ['title'] );
+
+=head2 fetchrow_hashref
 
 Accepts some SQL and other optional values, prepares and executes the query,
 and returns the first row as a hashref.
@@ -1065,21 +1095,21 @@ The following methods are available from statement handle objects. These along
 with inherritted L<DBI> statement handle methods are available from statement
 handle objects returned from a variety of L<DBIx::Query> methods.
 
-=head2 where()
+=head2 where
 
 If and only if you use C<get()> to construct your statement handle, you can
 optionally use C<where()> to add or alter the where clause.
 
     # data where a = 42
-    $dq->get('data')->where( 'a' => 42 )->run()->all({});
+    $dq->get('data')->where( 'a' => 42 )->run->all({});
 
     # data where a = 13 (original where is altered)
-    $dq->get( 'data', undef, { 'a' => 42 } )->where( 'a' => 13 )->run()->all({});
+    $dq->get( 'data', undef, { 'a' => 42 } )->where( 'a' => 13 )->run->all({});
 
     # data where a = 42 and b = 13 (original where is appended to)
-    $dq->get( 'data', undef, { 'a' => 42 } )->where( 'b' => 13 )->run()->all({});
+    $dq->get( 'data', undef, { 'a' => 42 } )->where( 'b' => 13 )->run->all({});
 
-=head2 run()
+=head2 run
 
 Executes the statement handle. It will execute the handle with whatever
 parameters are passed in as variables. If no variables are provided, it will
@@ -1087,29 +1117,29 @@ execute the handle based on variables previously provided. Otherwise, it'll
 execute the handle without input. Then C<run()> will return a "row set" back.
 (See below for more details on row sets.)
 
-    my $row_set_0 = $dq->sql('SELECT a, b FROM data WHERE x = 42')->run();
+    my $row_set_0 = $dq->sql('SELECT a, b FROM data WHERE x = 42')->run;
     my $row_set_1 = $dq->sql('SELECT a, b FROM data WHERE x = ?')->run(42);
-    my $row_set_2 = $dq->sql('SELECT a, b FROM data WHERE x = ?', undef, undef, [42] )->run();
-    my $row_set_3 = $dq->get( 'data', [ 'a', 'b' ], { 'x' => 42 } )->run();
+    my $row_set_2 = $dq->sql('SELECT a, b FROM data WHERE x = ?', undef, undef, [42] )->run;
+    my $row_set_3 = $dq->get( 'data', [ 'a', 'b' ], { 'x' => 42 } )->run;
 
-=head2 sql()
+=head2 sql
 
 Returns a string consisting of the SQL the statement handle has.
 
-=head2 structure()
+=head2 structure
 
 Returns a data structure consisting of the parsed SQL the statement handle has,
 if that structure is available. This is fulfilled using L<SQL::Parser>.
 (See C<SQL::Parser> for details of the returned data.)
 
-=head2 table()
+=head2 table
 
 Returns the primary table of the SQL for the statement handle. This is just a
 short-cut to:
 
-    $sth->structure()->{'table_names'}[0]
+    $sth->structure->{'table_names'}[0]
 
-=head2 up()
+=head2 up
 
 When called against a statement handle, returns the database object.
 
@@ -1118,25 +1148,25 @@ When called against a statement handle, returns the database object.
 Row sets are returned from C<run()> called on a statement handle. The represent
 a group or set of rows the database has or will return.
 
-=head2 next()
+=head2 next
 
 If you consider that a row set is a container for some number of rows, this
 method returns the next row of the set.
 
-    my $row = $db->sql($sql)->run()->next();
+    my $row = $db->sql($sql)->run->next;
 
 You can pass an integer into C<next()> to tell it to skip a certain number of
 rows and return to you the next after that skip.
 
-=head2 all()
+=head2 all
 
 A simple dumper of data for the given row set. This operates like L<DBI>'s
 C<fetchall_arrayref()> on an executed statement handle.
 
-    my $arrayref_of_arrayrefs = $db->sql($sql)->run()->all();
-    my $arrayref_of_hashrefs  = $db->sql($sql)->run()->all({});
+    my $arrayref_of_arrayrefs = $db->sql($sql)->run->all;
+    my $arrayref_of_hashrefs  = $db->sql($sql)->run->all({});
 
-=head2 each()
+=head2 each
 
 This is a row iterator that lets you run a block of code against each row in a
 row set. After running the code block against each row, the method returns a
@@ -1144,49 +1174,49 @@ reference to the object from which the method was called. The code block will
 get passed to it a row object. (See below.)
 
     use Data::Dumper 'Dumper';
-    my $dq0 = $dq->sql('SELECT a, b, c FROM data')->run()->each( sub {
+    my $dq0 = $dq->sql('SELECT a, b, c FROM data')->run->each( sub {
         my ($row) = @_;
-        print Dumper( $row->data() ), "\n";
+        print Dumper( $row->data ), "\n";
     } );
 
-=head2 value()
+=head2 value
 
 This method returns the value (or values) of the first row of a returned data
 set. The assumption is that the query is expecting only a single returned row
 of data.
 
-    my $value  = $dq->sql('SELECT a FROM data LIMIT 1')->run()->value();
-    my @values = $dq->sql('SELECT a, b FROM data LIMIT 1')->run()->value();
+    my $value  = $dq->sql('SELECT a FROM data LIMIT 1')->run->value;
+    my @values = $dq->sql('SELECT a, b FROM data LIMIT 1')->run->value;
 
 If in scalar context, the method assumes there is only a column returned and
 returns that value only. If there are multiple columns but the method is called
 in scalar context, the method throws an error. (If there are multiple rows
 found, only the first row's data will be returned, and no error will be thrown.)
 
-=head2 first()
+=head2 first
 
 Returns the first record. Has a similar interface to C<all()> in that it'll
 normally return an arrayref of data, but if you pass in an empty hashref, it'll
 return a hashref of data.
 
-    my $arrayref = $db->sql($sql)->run()->first();
-    my $hashref  = $db->sql($sql)->run()->first({});
+    my $arrayref = $db->sql($sql)->run->first;
+    my $hashref  = $db->sql($sql)->run->first({});
 
 If there are more than 1 rows the query will select, only the first row is
 returned.
 
-=head2 column()
+=head2 column
 
 Assuming a query that's going to return a column of data, this method will
 return the column of data as a list or an arrayref depending on context.
 
-    my $arrayref = $db->sql($sql)->run()->column();
-    my @array    = $db->sql($sql)->run()->column();
+    my $arrayref = $db->sql($sql)->run->column;
+    my @array    = $db->sql($sql)->run->column;
 
 If there are more than 1 columns requested in the query, only the first column
 is returned.
 
-=head2 up()
+=head2 up
 
 When called against a row set object, returns the statement handle.
 
@@ -1195,60 +1225,60 @@ When called against a row set object, returns the statement handle.
 Row objects are returned from row set methods like C<next()>. They represent
 a single row of returned database data.
 
-=head2 cell()
+=head2 cell
 
 Returns a cell object of the cell requested by index. The index can be
 the name of the column (which is usually but not always available) or the
 integer index (which is available if columns are specified in the query).
 
-    print $dq->sql('SELECT * FROM data WHERE a = ?')->run(42)->next()->cell('b')->value(), "\n";
-    print $dq->get('data')->run()->next()->cell('b')->value(), "\n";
+    print $dq->sql('SELECT * FROM data WHERE a = ?')->run(42)->next->cell('b')->value, "\n";
+    print $dq->get('data')->run->next->cell('b')->value, "\n";
 
     # returns column "b" value
-    print $dq->sql('SELECT a, b FROM data WHERE a = ?')->run(42)->next()->cell(1)->value(), "\n";
+    print $dq->sql('SELECT a, b FROM data WHERE a = ?')->run(42)->next->cell(1)->value, "\n";
 
 If columns are not specified in the query and an integer index is used, an
 error will be thrown.
 
     # don't do this...
-    eval { $dq->sql('SELECT * FROM data WHERE a = ?')->run(42)->next()->cell(1)->value() };
+    eval { $dq->sql('SELECT * FROM data WHERE a = ?')->run(42)->next->cell(1)->value };
 
 Optionally, this method will set the value of the cell (in memory only, not in
 the database yet) based on an index and new value.
 
-    print $dq->get('data')->run()->next()->cell( 'b', 'New Value' )->value(), "\n";
+    print $dq->get('data')->run->next->cell( 'b', 'New Value' )->value, "\n";
 
-=head2 each()
+=head2 each
 
 Similar to C<each()> from the row set object, C<each()> on a row object will
 execute a subroutine on each cell of the row. The subroutine reference is passed
 a cell object.
 
-    $dq->sql('SELECT a, b, c FROM data')->run()->next()->each( sub {
+    $dq->sql('SELECT a, b, c FROM data')->run->next->each( sub {
         my ($cell) = @_;
-        print $cell->value(), "\n";
+        print $cell->value, "\n";
     } );
 
 This method will only work if the query in question has some form of columns
 defined, either through C<sql()> or C<get()> with a column reference. Otherwise,
 it will throw an error.
 
-=head2 data()
+=head2 data
 
 Returns the data of the row as a hashref.
 
-    my $hashref = $dq->get('data')->run()->next()->data();
+    my $hashref = $dq->get('data')->run->next->data;
 
 In some situations with very complex SQL, the SQL parser will fail. In those
 cases, C<data()> cannot be used. Instead, use C<row()>.
 
-=head2 row()
+=head2 row
 
 Returns the data of the row as an arrayref.
 
-    my $arrayref = $dq->get('data')->run()->next()->data();
+    my $arrayref = $dq->get('data')->run->next->data;
 
-=head2 save()
+=head2 save
 
 Saves back to the database the row. It requires a scalar or arrayref "key"
 representing the primary key or keys (or enough data that a where clause will
@@ -1262,13 +1292,13 @@ Once the update is complete, the method will return a fresh row object pulled
 from the database using the where clause generated based on the key or keys.
 The third argument is an optional cache type for the inner SQL execution call.
 
-    my $row = $dq->sql('SELECT id, name FROM data')->run()->next();
+    my $row = $dq->sql('SELECT id, name FROM data')->run->next;
 
-    $row->cell( 'name', 'New Value' )->up()->save('id');
+    $row->cell( 'name', 'New Value' )->up->save('id');
     $row->save( 'id', { 'name' => 'New Value' } );
     $row->save( 'id', { 'name' => 'New Value' }, 0 );
 
-=head2 up()
+=head2 up
 
 When called against a row object, returns the row set handle.
 
@@ -1277,35 +1307,35 @@ When called against a row object, returns the row set handle.
 Cell objects are returned by calling C<cell()> on a row. They represent a
 single cell of returned database data.
 
-=head2 name()
+=head2 name
 
 Returns the name of the cell.
 
-    my $cell = $dq->sql('SELECT id, name FROM data')->run()->next()->cell('id');
+    my $cell = $dq->sql('SELECT id, name FROM data')->run->next->cell('id');
     $cell->name(); # returns "id"
 
-=head2 value()
+=head2 value
 
 Returns the value of the cell.
 
-    my $cell = $dq->sql('SELECT id, name FROM data')->run()->next()->cell('name');
-    $cell->value();
+    my $cell = $dq->sql('SELECT id, name FROM data')->run->next->cell('name');
+    $cell->value;
 
-=head2 index()
+=head2 index
 
 Returns the index of the cell.
 
-=head2 save()
+=head2 save
 
 Saves any changes to the row the cell is part of by calling C<save()> on that
 row. For example, the last two lines here are identical:
 
-    my $row = $dq->sql('SELECT id, name FROM data')->run()->next();
+    my $row = $dq->sql('SELECT id, name FROM data')->run->next;
 
-    $row->cell( 'name' => 'New Value' )->up()->save('id');
+    $row->cell( 'name' => 'New Value' )->up->save('id');
     $row->cell( 'name' => 'New Value' )->save('id');
 
-=head2 up()
+=head2 up
 
 When called against a cell object, returns the row object to which it belongs.
 
